pub struct Cash {
    pub currency: String,
    pub amount: i64,
}

impl Cash {
    pub fn create(currency: &str, amount: i64) -> Self {
        Self {
            currency: String::from(currency),
            amount: amount,
        }
    }
}